﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;

public partial class FileBrowser : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            string dirString = @"C:\";
            lblCurrentDirectory.Text = dirString;
            ShowDirectories(dirString);
            ShowFiles(dirString);
        }
    }

    private void ShowDirectories(string dir)
    {
        lstDirs.Items.Clear();
        DirectoryInfo dirInfo = new DirectoryInfo(dir);

        if (dirInfo.Root.Name != dirInfo.Name) lstDirs.Items.Add("..");
        foreach (DirectoryInfo subDirInfo in dirInfo.GetDirectories())
        {
            lstDirs.Items.Add(subDirInfo.Name);
        }

        /* 데이터 바인딩 이용
         * 상위 디렉터리로의 이동 항목을 넣을 수 없다.
        DirectoryInfo dirInfo = new DirectoryInfo(dir);
        lstDirs.DataSource = dirInfo.GetDirectories();
        lstDirs.DataMember = "Name";
        lstDirs.DataBind();
        */
    }

    private void ShowFiles(string dir)
    {
        lblFileInfo.Text = "";
        DirectoryInfo dirInfo = new DirectoryInfo(dir);
        lstFiles.DataSource = dirInfo.GetFiles();
        lstFiles.DataMember = "Name";
        lstFiles.DataBind();
    }

    protected void lstDirs_SelectedIndexChanged(object sender, EventArgs e) {
	    string selectedDir = "";
	    if (lstDirs.SelectedItem.Text == "..") {
		    // Directory의 GetParent 메서드를 통해 부모 디렉터리 경로 만듦
		    selectedDir = Directory.GetParent(lblCurrentDirectory.Text).FullName;
	    }
	    else {
		    // Path의 Combine 메서드를 통해 하위 디렉터리 경로 만듦
		    selectedDir = Path.Combine(lblCurrentDirectory.Text, lstDirs.SelectedItem.Text);
	    }
	    lblCurrentDirectory.Text = selectedDir;
	    ShowDirectories(selectedDir);
	    ShowFiles(selectedDir);
    }

    protected void lstFiles_SelectedIndexChanged(object sender, EventArgs e)
    {
        string fileName = Path.Combine(lblCurrentDirectory.Text,
            lstFiles.SelectedItem.Text);
        System.Text.StringBuilder displayString = new System.Text.StringBuilder();
        FileInfo selectedFile = new FileInfo(fileName);
        displayString.Append("<b>");
        displayString.Append(selectedFile.Name);
        displayString.Append("</b><br /><br />");
        displayString.Append("파일 크기 : ");
        displayString.Append(selectedFile.Length);
        displayString.Append("&nbsp;Bytes<br />");
        displayString.Append("생성 시각 : ");
        displayString.Append(selectedFile.CreationTime.ToString());
        displayString.Append("<br />");
        displayString.Append("최종 접근 시각 : ");
        displayString.Append(selectedFile.LastAccessTime.ToString());
        displayString.Append("<br />");

        lblFileInfo.Text = displayString.ToString();
    }
}
